@@ -1,5 +1,5 @@
 import arcade
-from arcade.sprite_list import SpriteList, _check_for_collision
+from arcade.sprite_list import SpriteList, check_for_collision
 from arcade import check_for_collision_with_list
 from itertools import chain, combinations
 from collections import defaultdict
@@ -72,6 +72,7 @@ class ContinuousPhysicsEngine(QuestPhysicsEngine):
     def resolve_collisions_with_walls(self):
         """Resolves collisions between every sprite and every wall.
         """
+
         for moving_sprite in self.non_wall_list:
             if moving_sprite.change_x == 0 and moving_sprite.change_y == 0:
                 continue
@@ -92,7 +93,7 @@ class ContinuousPhysicsEngine(QuestPhysicsEngine):
         sprite.stop()
         repel_distance = 1
         away = (wall.center_x - sprite.center_x, wall.center_y - sprite.center_y)
-        while _check_for_collision(sprite, wall):
+        while check_for_collision(sprite, wall):
             away_x, away_y = scale(away, repel_distance)
             sprite.center_x = sprite.center_x - away_x
             sprite.center_y = sprite.center_y - away_y
@@ -102,7 +103,7 @@ class ContinuousPhysicsEngine(QuestPhysicsEngine):
         """For every pair of nonwall sprites, resolves collisions.
         """
         for sprite0, sprite1 in combinations(self.non_wall_list, 2):
-            if _check_for_collision(sprite0, sprite1):
+            if check_for_collision(sprite0, sprite1):
                 sprite0.on_collision(sprite1, self.game)
                 sprite1.on_collision(sprite0, self.game)
 
